@@ -2,12 +2,11 @@
 #![feature(unboxed_closures)]
 #![feature(collections)]
 #![feature(rustc_private)]
-#![feature(env)]
-#![feature(core)]
+#![feature(step_by)]
 
 extern crate gnuplot;
 
-use std::iter::{repeat, range_step};
+use std::iter::repeat;
 
 use gnuplot::*;
 use common::*;
@@ -72,8 +71,8 @@ fn example(c: Common)
 	fg.axes2d()
 	.set_title("Axis Ticks", &[])
 	.lines(x3, y3, &[LineWidth(2.0), Color("blue")])
-	.set_x_ticks_custom(range_step(0, 10, 2).map(|x| Major(x as f32, Fix("%.2f ms".to_string())))
-	                    .chain(range_step(1, 10, 2).map(|x| Minor(x as f32))).chain(Some(Major(-2.1f32, Fix("%.2f ms".to_string()))).into_iter()), 
+	.set_x_ticks_custom((0..10).step_by(2).map(|x| Major(x as f32, Fix("%.2f ms".to_string())))
+	                    .chain((1..10).step_by(2).map(|x| Minor(x as f32))).chain(Some(Major(-2.1f32, Fix("%.2f ms".to_string()))).into_iter()),
 						&[MajorScale(2.0), MinorScale(0.5), OnAxis(true)], &[TextColor("blue"), TextAlign(AlignCenter)])
 	.set_y_ticks(Some((Fix(2.0), 1)), &[Mirror(false)], &[]);
 	
