@@ -2,12 +2,9 @@
 #![feature(unboxed_closures)]
 #![feature(collections)]
 #![feature(rustc_private)]
-#![feature(env)]
 
 extern crate gnuplot;
 
-use std::num::Float;
-
 use gnuplot::*;
 use common::*;
 
